import React, { useState, useEffect } from 'react';
import { motion, AnimatePresence } from 'framer-motion';
import { Plus, X, Github, Globe } from 'lucide-react';

interface Project {
  id: string;
  title: string;
  description: string;
  image: string;
  github?: string;
  website?: string;
  tags: string[];
}

export default function Projects() {
  const [isAdmin, setIsAdmin] = useState(false);
  const [showAddForm, setShowAddForm] = useState(false);
  const [projects, setProjects] = useState<Project[]>(() => {
    const saved = localStorage.getItem('projects');
    try {
      return saved ? JSON.parse(saved) : [];
    } catch {
      localStorage.removeItem('projects');
      return [];
    }
  });

  useEffect(() => {
    localStorage.setItem('projects', JSON.stringify(projects));
  }, [projects]);

  const toggleAdmin = () => {
    const password = window.prompt('Enter admin password:');
    if (password === 'O8kocwmnVyW6AF') {
      setIsAdmin(true);
    } else {
      alert('Incorrect password.');
    }
  };

  const handleAddProject = (e: React.FormEvent<HTMLFormElement>) => {
    e.preventDefault();
    const form = e.currentTarget;
    const formData = new FormData(form);

    const newProject: Project = {
      id: Date.now().toString(),
      title: formData.get('title') as string,
      description: formData.get('description') as string,
      image: formData.get('image') as string,
      github: formData.get('github') as string || undefined,
      website: formData.get('website') as string || undefined,
      tags: (formData.get('tags') as string)
        .split(',')
        .map(tag => tag.trim())
        .filter(tag => tag),
    };

    setProjects(prev => [...prev, newProject]);
    setShowAddForm(false);
    form.reset();
  };

  const deleteProject = (id: string) => {
    setProjects(prev => prev.filter(p => p.id !== id));
  };

  return (
    <motion.div
      initial={{ opacity: 0 }}
      animate={{ opacity: 1 }}
      exit={{ opacity: 0 }}
      className="max-w-6xl mx-auto px-6 py-16"
    >
      <div className="flex justify-between items-center mb-12">
        <h1 className="text-4xl font-bold">Projects</h1>
        {isAdmin ? (
          <button
            onClick={() => setShowAddForm(true)}
            className="flex items-center space-x-2 bg-cyan-500 hover:bg-cyan-600 text-white px-4 py-2 rounded-lg transition-colors"
          >
            <Plus className="w-5 h-5" />
            <span>Add Project</span>
          </button>
        ) : (
          <span
            onClick={toggleAdmin}
            className="w-2 h-2 rounded-full bg-gray-800 hover:bg-gray-700 cursor-pointer transition-colors"
            aria-label="Admin toggle"
          />
        )}
      </div>

      <div className="grid grid-cols-1 md:grid-cols-2 lg:grid-cols-3 gap-8">
        <AnimatePresence>
          {projects.map(project => (
            <motion.div
              key={project.id}
              initial={{ opacity: 0, y: 20 }}
              animate={{ opacity: 1, y: 0 }}
              exit={{ opacity: 0, y: -20 }}
              className="bg-gray-800 rounded-xl overflow-hidden"
            >
              <img
                src={project.image}
                alt={project.title}
                className="w-full h-48 object-cover"
              />
              <div className="p-6">
                <div className="flex justify-between items-start">
                  <h3 className="text-xl font-bold mb-2">{project.title}</h3>
                  {isAdmin && (
                    <button
                      onClick={() => deleteProject(project.id)}
                      className="text-gray-400 hover:text-red-500 transition-colors"
                      aria-label={`Delete project ${project.title}`}
                    >
                      <X className="w-5 h-5" />
                    </button>
                  )}
                </div>
                <p className="text-gray-400 mb-4">{project.description}</p>
                <div className="flex flex-wrap gap-2 mb-4">
                  {project.tags.map(tag => (
                    <span
                      key={tag}
                      className="bg-gray-700 text-cyan-400 text-sm px-3 py-1 rounded-full"
                    >
                      {tag}
                    </span>
                  ))}
                </div>
                <div className="flex space-x-4">
                  {project.github && (
                    <a
                      href={project.github}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-gray-400 hover:text-cyan-400 transition-colors"
                      aria-label="GitHub link"
                    >
                      <Github className="w-5 h-5" />
                    </a>
                  )}
                  {project.website && (
                    <a
                      href={project.website}
                      target="_blank"
                      rel="noopener noreferrer"
                      className="text-gray-400 hover:text-cyan-400 transition-colors"
                      aria-label="Website link"
                    >
                      <Globe className="w-5 h-5" />
                    </a>
                  )}
                </div>
              </div>
            </motion.div>
          ))}
        </AnimatePresence>
      </div>

      {showAddForm && (
        <div className="fixed inset-0 bg-black/50 flex items-center justify-center p-4 z-50">
          <motion.div
            initial={{ opacity: 0, scale: 0.9 }}
            animate={{ opacity: 1, scale: 1 }}
            exit={{ opacity: 0, scale: 0.9 }}
            className="bg-gray-800 rounded-xl p-6 max-w-md w-full"
          >
            <div className="flex justify-between items-center mb-6">
              <h2 className="text-2xl font-bold">Add New Project</h2>
              <button
                onClick={() => setShowAddForm(false)}
                className="text-gray-400 hover:text-red-500 transition-colors"
                aria-label="Close add project form"
              >
                <X className="w-6 h-6" />
              </button>
            </div>

            <form onSubmit={handleAddProject} className="space-y-4">
              {/* Input fields */}
              {/* ... */}

              <button
                type="submit"
                className="w-full bg-cyan-500 hover:bg-cyan-600 text-white py-2 rounded-lg transition-colors"
              >
                Add Project
              </button>
            </form>
          </motion.div>
        </div>
      )}
    </motion.div>
  );
}
